@@ -9,7 +9,9 @@ export class Trimmer extends Component {
 		width: PropTypes.number,
 		height: PropTypes.number,
 		themeColor: PropTypes.string,
-		onChange: PropTypes.func
+		onChange: PropTypes.func,
+		minLength: PropTypes.number,
+		maxLength: PropTypes.number
 	};
 
 	static defaultProps = {
@@ -30,7 +32,7 @@ export class Trimmer extends Component {
 	}
 
 	render() {
-		const { source, width, height, themeColor } = this.props;
+		const { source, width, height, themeColor, minLength, maxLength } = this.props;
 		const actualSource = getActualSource(source);
 		return (
 			<RNTrimmer
@@ -40,6 +42,8 @@ export class Trimmer extends Component {
 				themeColor={processColor(themeColor).toString()}
 				pointerEvents={'box-none'}
 				onChange={this._onChange}
+				minLength={minLength}
+				maxLength={maxLength}
 			/>
 		);
 	}
